import { Params } from '@angular/router';
import { HttpHeaders, HttpParams } from '@angular/common/http';
export interface AppContract {
    name: string;
    slogan: string;
    logo: ImageContract;
    smallLogo?: ImageContract;
    bigLogo?: ImageContract;
    url?: LinkContract;
    contact?: ContactContract;
    dateTime?: string;
    version?: string;
    year?: string;
}
export interface ContactContract {
    address?: string;
    telephone?: string;
    email: string;
}
export interface TimeContract {
    hour?: number;
    minute?: number;
    second?: number;
    millisecond?: number;
}
export interface DateContract {
    day: number;
    week?: number;
    month: number;
    year: number;
    dayOfYear?: number;
}
export interface DateTimeContract extends DateContract, TimeContract {
}
export interface ErrorContract {
    code?: string;
    title: string;
    message: string;
    detail?: string;
}
export interface ImageContract {
    title?: string;
    url?: string;
}
export interface JSONContract extends Object {
    [title: string]: any;
}
export interface LinkContract {
    title?: string;
    url?: string;
    children?: LinkContract[];
    queryParams?: Params;
    fragment?: string;
    id?: string;
    icon?: string;
    label?: string;
}
export interface ActionContract extends LinkContract {
    index?: number;
    type?: string;
    data?: Object;
    isBreadcrumb?: boolean;
    children?: ActionContract[];
    column?: boolean;
}
export interface ModelContract {
    id?: string;
    status?: 'pristine' | 'active' | 'inactive';
    createdAt?: DateTimeContract;
    updatedAt?: DateTimeContract;
    [key: string]: any;
}
export declare type UserContract = Partial<{
    id: string;
    name: string;
    email: string;
    summary: string;
    avatar: ImageContract;
    password: string;
    token: string;
}>;
export interface SnippetContract {
    title: string;
    desc: string;
    actions: ActionContract[];
}
export interface PairContract {
    key: string;
    value: any;
}
export interface PageContract {
    key: string;
    title: string;
    desc: string;
    detail: string;
    actions?: ActionContract[];
    tags: string[];
    avatar?: ImageContract;
    banner?: ImageContract;
    status: string[];
}
export interface ErrorContract {
    code?: string;
    title: string;
    message: string;
    detail?: string;
}
export interface XformContract {
    to<T>(data: any): T;
}
export interface Response<M> {
    status?: string | 'success' | 'fail' | 'error';
    data?: any;
    message?: string;
    code?: number;
}
export interface HttpOptions {
    body?: any;
    headers?: HttpHeaders | {
        [header: string]: string | string[];
    };
    reportProgress?: boolean;
    observe: 'response';
    params?: HttpParams | {
        [param: string]: string | string[];
    };
    responseType?: 'json';
    withCredentials?: boolean;
}
export interface AppTheme {
    name: string;
    actions: {
        primary: ActionContract[];
        secondary: ActionContract[];
        tertiart: ActionContract[];
    };
}
export interface FormContract {
    fields: any[];
    title?: string;
    buttonName?: string;
    buttonClass?: string;
    hasReset?: boolean;
    color?: string;
    resource?: Object;
    description?: string;
    actions?: ActionContract[];
    type?: string;
}
